@@ -431,9 +431,7 @@ def get_ppid(mypid=os.getpid()):
         # LP: #1101304
         # 9983 (cmd) S 923 ...
         # 9983 (cmd with spaces) S 923 ...
-        # LP: #2015645
-        # 229 (cmd(withparen)) S 228 ...
-        ppid = open(name).readlines()[0].rsplit(")", 1)[1].split()[1]
+        ppid = open(name).readlines()[0].split(')')[1].split()[1]
     except Exception: # pragma: no cover
         raise
 
